Learn R Programming

mvprpb (version 1.0.4)

mvprpb-package: mvprpb

Description

Evaluation orthant probabilities of non-degenerate multivariate normal distribution based on orthogonal projections to subspaces.

Arguments

Details

Package:
mvprpb
Type:
Package
Version:
1.0.4
Date:
2014-10-06
License:
BSD_3_clause License
This program evaluates the probabilites of multivariate distribution based on orthogonal projections to subspaces.

References

Nomura N. (2014). Evaluation of Gaussian orthant probabilities based on orthogonal projections to subspaces. Statistics and Computing, Online First.

Examples

Run this code
dim.p <- 8
mu   <- c( rep(- 0.5   , dim.p -1) , 3 )
cov  <-  diag( dim.p )  * 0.5 + 0.5
n.itr <- 800
integ.range <- 10
res.val <-  mvorpb( dim.p , mu , cov  ,n.itr , integ.range )
print(res.val)

Run the code above in your browser using DataLab